==> Paws-0.29.tar.gz: Paws-0.29/lib/Paws/Credential/AssumeRoleWithSAML.pm <==
package Paws::Credential::AssumeRoleWithSAML;
  use Moose;
  use DateTime;
  use DateTime::Format::ISO8601;
  use Paws::Credential::None;

  with 'Paws::Credential';

  has expiration => (
    is => 'rw',
    isa => 'DateTime',
    lazy => 1,
    default => sub {
      DateTime->from_epoch(epoch => 0); # need a better way to do this
    }
  );

  has actual_creds => (is => 'rw');

  sub access_key {
    my $self = shift;
    $self->_refresh;
    $self->actual_creds->AccessKeyId;
  }

  sub secret_key {
    my $self = shift;
    $self->_refresh;
    $self->actual_creds->SecretAccessKey;
  }

  sub session_token {
    my $self = shift;
    $self->_refresh;
    $self->actual_creds->SessionToken;
  }

  has sts_region => (is => 'ro', isa => 'Str|Undef', default => sub { undef });

  has sts => (is => 'ro', isa => 'Paws::STS', lazy => 1, default => sub {
    my $self = shift;
    Paws->service('STS', region => $self->sts_region, credentials => Paws::Credential::None->new);
  });

  has DurationSeconds => (is => 'rw', isa => 'Maybe[Int]');
  has Policy => (is => 'rw', isa => 'Maybe[Str]');

  has RoleArn => (is => 'rw', isa => 'Str', required => 1);
  has PrincipalArn => (is => 'rw', isa => 'Str', required => 1);
  has SAMLAssertion => (is => 'rw', isa => 'Str', required => 1);

  sub _refresh {
    my $self = shift;

    return if (($self->expiration - DateTime->now())->is_positive);

    my $result = $self->sts->AssumeRoleWithSAML(
      RoleArn => $self->RoleArn,
      PrincipalArn => $self->PrincipalArn,
      SAMLAssertion => $self->SAMLAssertion,
      (defined $self->DurationSeconds) ? (DurationSeconds => $self->DurationSeconds) : (),
      (defined $self->Policy) ? (Policy => $self->Policy) : (),
    );

    my $creds = $self->actual_creds($result->Credentials);

    $self->expiration(DateTime::Format::ISO8601->parse_datetime($result->Credentials->Expiration));
  }

  no Moose;

1;

==> Paws-0.44.tar.gz: Paws-0.44/lib/Paws/Credential/AssumeRoleWithSAML.pm <==
package Paws::Credential::AssumeRoleWithSAML;
  use Moose;
  use DateTime::Format::ISO8601;
  use Paws::Credential::None;

  with 'Paws::Credential';

  has expiration => (
    is => 'rw',
    isa => 'Int',
    lazy => 1,
    default => sub { 0 }
  );

  has actual_creds => (is => 'rw');

  sub access_key {
    my $self = shift;
    $self->_refresh;
    $self->actual_creds->AccessKeyId;
  }

  sub secret_key {
    my $self = shift;
    $self->_refresh;
    $self->actual_creds->SecretAccessKey;
  }

  sub session_token {
    my $self = shift;
    $self->_refresh;
    $self->actual_creds->SessionToken;
  }

  has sts_region => (is => 'ro', isa => 'Str|Undef', default => sub { undef });

  has sts => (is => 'ro', isa => 'Paws::STS', lazy => 1, default => sub {
    my $self = shift;
    Paws->service('STS', region => $self->sts_region, credentials => Paws::Credential::None->new);
  });

  has DurationSeconds => (is => 'rw', isa => 'Maybe[Int]');
  has Policy => (is => 'rw', isa => 'Maybe[Str]');

  has RoleArn => (is => 'rw', isa => 'Str', required => 1);
  has PrincipalArn => (is => 'rw', isa => 'Str', required => 1);
  has SAMLAssertion => (is => 'rw', isa => 'Str', required => 1);

  sub _refresh {
    my $self = shift;

    return if $self->expiration >= time;

    my $result = $self->sts->AssumeRoleWithSAML(
      RoleArn => $self->RoleArn,
      PrincipalArn => $self->PrincipalArn,
      SAMLAssertion => $self->SAMLAssertion,
      (defined $self->DurationSeconds) ? (DurationSeconds => $self->DurationSeconds) : (),
      (defined $self->Policy) ? (Policy => $self->Policy) : (),
    );

    my $creds = $self->actual_creds($result->Credentials);

    $self->expiration(DateTime::Format::ISO8601->parse_datetime($result->Credentials->Expiration)->epoch);
  }

  no Moose;

1;
